@@ -105,7 +105,7 @@ namespace {
       const glibtop_sysinfo *info = glibtop_get_sysinfo();
 
       for (guint i = 0; i != info->ncpu; ++i) {
-	const char * const keys[] = { "model name", "cpu" };
+	const char * const keys[] = { "model name", "cpu", "Processor" };
 	gchar *model = 0;
 
 	for (guint j = 0; !model && j != G_N_ELEMENTS(keys); ++j)
@@ -113,7 +113,7 @@ namespace {
 							 keys[j]));
 
 	if (!model)
-	  model = _("Unknown CPU model");
+          continue;
 
 	this->processors.push_back(model);
       }
@@ -183,7 +183,7 @@ namespace {
 	{
 	  xmlXPathObjectPtr xpath;
 	  xpath = xmlXPathEvalExpression(BAD_CAST nodes[i].c_str(), context);
-	  
+
 	  if (xpath and xpath->type == XPATH_STRING)
 	    values[i] = reinterpret_cast<const char*>(xpath->stringval);
 
@@ -412,9 +412,9 @@ namespace {
 #define RADIUS 5
 
 static gboolean
-sysinfo_logo_expose (GtkWidget *widget,
-		     GdkEventExpose *event,
-		     gpointer data_ptr)
+sysinfo_logo_draw (GtkWidget *widget,
+                   cairo_t *context,
+                   gpointer data_ptr)
 {
   GtkAllocation allocation;
   GtkStyle *style;
@@ -488,7 +488,7 @@ add_section(GtkBox *vbox , const char * title, int num_row, int num_col, GtkWidg
 }
 
 
-static GtkWidget* 
+static GtkWidget*
 add_row(GtkTable * table, const char * label, const char * value, int row)
 {
   GtkWidget *header = gtk_label_new(label);
@@ -546,8 +546,8 @@ procman_create_sysinfo_view(void)
   gtk_misc_set_padding(GTK_MISC(logo), 5, 12);
   gtk_box_pack_start(GTK_BOX(hbox), logo, FALSE, FALSE, 0);
 
-  g_signal_connect(G_OBJECT(logo), "expose-event",
-		   G_CALLBACK(sysinfo_logo_expose), NULL);
+  g_signal_connect(G_OBJECT(logo), "draw",
+		   G_CALLBACK(sysinfo_logo_draw), NULL);
 
   vbox = gtk_vbox_new(FALSE, 12);
   gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
@@ -648,7 +648,7 @@ procman_create_sysinfo_view(void)
   g_free(markup);
 
   markup = procman::format_size(data->free_space_bytes);
-  disk_space_label = add_row(GTK_TABLE(disk_space_table), 
+  disk_space_label = add_row(GTK_TABLE(disk_space_table),
                              _("Available disk space:"), markup,
                              0);
   g_free(markup);
